@@ -1,8 +1,8 @@
-det.batchID <- function ()
+det.batchID <- function (geno.files)
 {
        batchID = NULL
-        
-        for (i in 1:length(geno.files))
+ 
+        for (i in 1:seq_along(geno.files))
                  batchID = c(batchID,rep(i,nrow(get(geno.files[i]))))
       return(batchID)
 }
